@@ -1,6 +1,6 @@
 ;;; org-contacts.el --- Contacts management
 
-;; Copyright (C) 2010-2011 Julien Danjou <julien@danjou.info>
+;; Copyright (C) 2010-2012 Julien Danjou <julien@danjou.info>
 
 ;; Author: Julien Danjou <julien@danjou.info>
 ;; Keywords: outlines, hypermedia, calendar
@@ -143,7 +143,8 @@ This overrides `org-email-link-description-format' if set."
 (defun org-contacts-filter (&optional name-match tags-match)
   "Search for a contact maching NAME-MATCH and TAGS-MATCH.
 If both match values are nil, return all contacts."
-  (let ((tags-matcher
+  (let* (todo-only
+	(tags-matcher
          (if tags-match
              (cdr (org-make-tags-matcher tags-match))
            t))
@@ -161,7 +162,8 @@ If both match values are nil, return all contacts."
           (error "File %s is no in `org-mode'" file))
         (org-scan-tags
          '(add-to-list 'markers (set-marker (make-marker) (point)))
-         `(and ,contacts-matcher ,tags-matcher ,name-matcher))))
+         `(and ,contacts-matcher ,tags-matcher ,name-matcher)
+	 todo-only)))
     (dolist (marker markers result)
       (org-with-point-at marker
         (add-to-list 'result
@@ -388,7 +390,7 @@ This function should be called from `gnus-article-prepare-hook'."
   (let ((mails (org-entry-get (point) org-contacts-email-property)))
     (unless (member mail (split-string mails))
       (when (yes-or-no-p
-             (format "Do you want to this address to %s?" (org-get-heading t)))
+             (format "Do you want to add this address to %s?" (org-get-heading t)))
         (org-set-property org-contacts-email-property (concat mails " " mail))))))
 
 (defun org-contacts-gnus-check-mail-address ()
